@@ -23,7 +23,9 @@
 #include "breeze.h"
 #include "config-breeze.h"
 
+#if BREEZE_HAVE_KSTYLE
 #include <KStyle>
+#endif
 
 #include <QAbstractItemView>
 #include <QAbstractScrollArea>
@@ -48,13 +50,14 @@ namespace Breeze
     class Helper;
     class MdiWindowShadowFactory;
     class Mnemonics;
+    class PaletteHelper;
     class ShadowHelper;
     class SplitterFactory;
     class WidgetExplorer;
     class WindowManager;
 
     //* convenience typedef for base class
-    #if BREEZE_USE_KDE4
+    #if BREEZE_USE_KDE4 || !BREEZE_HAVE_KSTYLE
     using ParentStyleClass = QCommonStyle;
     #else
     using ParentStyleClass = KStyle;
@@ -123,7 +126,7 @@ namespace Breeze
         //@{
 
         virtual bool eventFilter(QObject *, QEvent *);
-        bool eventFilterScrollArea( QAbstractScrollArea*, QEvent* );
+        bool eventFilterScrollArea( QWidget*, QEvent* );
         bool eventFilterComboBoxContainer( QWidget*, QEvent* );
         bool eventFilterDockWidget( QDockWidget*, QEvent* );
         bool eventFilterMdiSubWindow( QMdiSubWindow*, QEvent* );
@@ -161,21 +164,22 @@ namespace Breeze
         QRect defaultSubElementRect( const QStyleOption* option, const QWidget* ) const
         { return option->rect; }
 
-        QRect pushButtonContentsRect( const QStyleOption* option, const QWidget* ) const;
-        QRect checkBoxContentsRect( const QStyleOption* option, const QWidget* ) const;
+        QRect pushButtonContentsRect( const QStyleOption*, const QWidget* ) const;
+        QRect checkBoxContentsRect( const QStyleOption*, const QWidget* ) const;
         QRect lineEditContentsRect( const QStyleOption*, const QWidget* ) const;
-        QRect progressBarGrooveRect( const QStyleOption* option, const QWidget* ) const;
-        QRect progressBarContentsRect( const QStyleOption* option, const QWidget* ) const;
-        QRect progressBarLabelRect( const QStyleOption* option, const QWidget* ) const;
-        QRect headerArrowRect( const QStyleOption* option, const QWidget* ) const;
-        QRect headerLabelRect( const QStyleOption* option, const QWidget* ) const;
+        QRect progressBarGrooveRect( const QStyleOption*, const QWidget* ) const;
+        QRect progressBarContentsRect( const QStyleOption*, const QWidget* ) const;
+        QRect progressBarLabelRect( const QStyleOption*, const QWidget* ) const;
+        QRect headerArrowRect( const QStyleOption*, const QWidget* ) const;
+        QRect headerLabelRect( const QStyleOption*, const QWidget* ) const;
         QRect tabBarTabLeftButtonRect( const QStyleOption*, const QWidget* ) const;
         QRect tabBarTabRightButtonRect( const QStyleOption*, const QWidget* ) const;
         QRect tabWidgetTabBarRect( const QStyleOption*, const QWidget* ) const;
         QRect tabWidgetTabContentsRect( const QStyleOption*, const QWidget* ) const;
         QRect tabWidgetTabPaneRect( const QStyleOption*, const QWidget* ) const;
-        QRect tabWidgetCornerRect( SubElement, const QStyleOption* option, const QWidget* widget ) const;
-        QRect toolBoxTabContentsRect( const QStyleOption* option, const QWidget* ) const;
+        QRect tabWidgetCornerRect( SubElement, const QStyleOption*, const QWidget* widget ) const;
+        QRect toolBoxTabContentsRect( const QStyleOption*, const QWidget* ) const;
+        QRect genericLayoutItemRect( const QStyleOption*, const QWidget* ) const;
 
         //@}
 
@@ -253,7 +257,7 @@ namespace Breeze
         bool drawIndicatorCheckBoxPrimitive( const QStyleOption*, QPainter*, const QWidget* ) const;
         bool drawIndicatorRadioButtonPrimitive( const QStyleOption*, QPainter*, const QWidget* ) const;
         bool drawIndicatorButtonDropDownPrimitive( const QStyleOption*, QPainter*, const QWidget* ) const;
-        bool drawIndicatorTabClosePrimitive( const QStyleOption* option, QPainter* painter, const QWidget* widget ) const;
+        bool drawIndicatorTabClosePrimitive( const QStyleOption*, QPainter* painter, const QWidget* widget ) const;
         bool drawIndicatorTabTearPrimitive( const QStyleOption*, QPainter*, const QWidget* ) const;
         bool drawIndicatorToolBarHandlePrimitive( const QStyleOption*, QPainter*, const QWidget* ) const;
         bool drawIndicatorToolBarSeparatorPrimitive( const QStyleOption*, QPainter*, const QWidget* ) const;
@@ -440,6 +444,9 @@ namespace Breeze
         //* helper
         Helper* _helper;
 
+        //* palette helper
+        PaletteHelper* _paletteHelper;
+
         //* shadow helper
         ShadowHelper* _shadowHelper;
 
@@ -468,17 +475,17 @@ namespace Breeze
         BreezePrivate::TabBarData* _tabBarData;
 
         //* icon hash
-        typedef QHash<StandardPixmap, QIcon> IconCache;
+        using IconCache = QHash<StandardPixmap, QIcon>;
         IconCache _iconCache;
 
         //* pointer to primitive specialized function
-        typedef bool (Style::*StylePrimitive)( const QStyleOption*, QPainter*, const QWidget* ) const;
+        using StylePrimitive = bool(Style::*)(const QStyleOption*, QPainter*, const QWidget* ) const;
 
         //* pointer to control specialized function
-        typedef bool (Style::*StyleControl)( const QStyleOption*, QPainter*, const QWidget* ) const;
+        using StyleControl = bool (Style::*)( const QStyleOption*, QPainter*, const QWidget* ) const;
 
         //* pointer to control specialized function
-        typedef bool (Style::*StyleComplexControl)( const QStyleOptionComplex*, QPainter*, const QWidget* ) const;
+        using StyleComplexControl = bool (Style::*)( const QStyleOptionComplex*, QPainter*, const QWidget* ) const;
 
         //*@name custom elements
         //@{
